@@ -49,8 +49,9 @@ class PackageBuild:
             'rm -rf dist',
             'rm -rf build'
         ])
+        self.git_clear_build()
 
-    def git_build_clear(self):
+    def git_clear_build(self):
         logger.info('{} build clear'.format(self.name))
         run_shell_list([
             'rm -rf {}.egg-info'.format(self.name),
@@ -63,7 +64,8 @@ class PackageBuild:
         git build
         """
         logger.info('{} build'.format(self.name))
-        self.git_build_clear()
+        self.git_pull()
+        self.git_clear_build()
         run_shell_list([
             'python3 setup.py build',  # 编译
             'python3 setup.py sdist',  # 生成 tar.gz
@@ -71,9 +73,10 @@ class PackageBuild:
             'python3 setup.py bdist_wheel',  # 生成 wheel 包
 
             # twine register dist/*
-            'twine upload dist/*',  # 发布包
+            'twine upload dist/*'  # 发布包
         ])
-        self.git_build_clear()
+        self.git_clear_build()
+        self.git_push()
 
     def git_clean_history(self):
         """
